pytest-dbfixtures
=================

.. image:: https://travis-ci.org/clearcode/pytest-dbfixtures.png?branch=master
    :target: https://travis-ci.org/clearcode/pytest-dbfixtures
    :alt: Tests for pytest-dbfixtures

.. image:: https://pypip.in/v/pytest-dbfixtures/badge.png
    :target: https://crate.io/packages/pytest-dbfixtures/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/pytest-dbfixtures/badge.png
    :target: https://crate.io/packages/pytest-dbfixtures/
    :alt: Number of PyPI downloads

Overview
--------

py.test clean fixtures for: ``mysql``, ``redis``, ``mongo``, ``rabbitmq``, ``postgresql`` and ``elasticsearch``.

Starts specific database deamon and cleanup all data produced during tests.


Install
-------

.. sourcecode:: bash

    $ pip install --upgrade pytest-dbfixtures


How to use
----------

Please see `documentation <http://pytest-dbfixtures.readthedocs.org/en/latest/howtouse.html>`_
